==> klayout-0.10.tar.gz: klayout-0.10/src/antConfig.h <==

/*

  KLayout Layout Viewer
  Copyright (C) 2006 Matthias Koefferlein

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

*/


#ifndef HDR_antConfig
#define HDR_antConfig

#include <string>
#include "antService.h"

namespace ant
{

/** 
 *  @brief Declaration of the configuration names
 */
extern const std::string cfg_max_number_of_rulers;
extern const std::string cfg_ruler_snap_range;
extern const std::string cfg_ruler_color;
extern const std::string cfg_ruler_snap_mode;
extern const std::string cfg_ruler_obj_snap;
extern const std::string cfg_ruler_grid_snap;
extern const std::string cfg_ruler_grid_micron;

// ------------------------------------------------------------
//  Helper functions to get and set the configuration

struct SnapModeConverter 
{
  std::string to_string (const ant::Service::SnapMode &m);
  void from_string (const std::string &s, ant::Service::SnapMode &m);
};

}

#endif

==> klayout-0.15.tar.gz: klayout-0.15/src/antConfig.h <==

/*

  KLayout Layout Viewer
  Copyright (C) 2006-2007 Matthias Koefferlein

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

*/


#ifndef HDR_antConfig
#define HDR_antConfig

#include <string>
#include "antService.h"

namespace ant
{

/** 
 *  @brief Declaration of the configuration names
 */
extern const std::string cfg_max_number_of_rulers;
extern const std::string cfg_ruler_snap_range;
extern const std::string cfg_ruler_color;
extern const std::string cfg_ruler_halo;
extern const std::string cfg_ruler_snap_mode;
extern const std::string cfg_ruler_obj_snap;
extern const std::string cfg_ruler_grid_snap;
extern const std::string cfg_ruler_grid_micron;
extern const std::string cfg_ruler_templates;
extern const std::string cfg_current_ruler_template;

// ------------------------------------------------------------
//  Helper functions to get and set the configuration

struct ACConverter 
{
  std::string to_string (const ant::Object::angle_constraint_type &m);
  void from_string (const std::string &s, ant::Object::angle_constraint_type &m);
};

struct StyleConverter 
{
  std::string to_string (ant::Object::style_type s);
  void from_string (const std::string &s, ant::Object::style_type &style);
};

struct OutlineConverter 
{
  std::string to_string (ant::Object::outline_type s);
  void from_string (const std::string &s, ant::Object::outline_type &outline);
};

struct TemplatesConverter 
{
  std::string to_string (const std::vector <ant::Template> &t);
  void from_string (const std::string &s, std::vector <ant::Template> &t);
};

}

#endif
